import cadquery2 as cq
from cadquery2 import exporters

shell_t = 2.5

# width, length VISIBLE WITHIN THE BEZEL
screen_w = 223
screen_l = 57
# Distance from the left of the case to screen cutout
screen_left_margin = 7 + shell_t  #  (7 is bezel width on that side)
# width, length, height INCLUDING_BEZEL
display_w = 233
display_l = 65
display_h = 5

width = 250
height = display_h + 2 * shell_t + 1
length = display_l + 2 * shell_t + 1
fillet_s = 2


# Distance from the left of the case to display end
display_left_margin = screen_left_margin - 7
# Distance from the right of the case to display end
display_right_margin = width - display_left_margin - display_w
# Distance from the top of the case to display top
display_top_margin = (length - display_l) / 2
display_bottom_margin = display_top_margin  # Symmetrical


screen_cutout = (
    cq.Sketch().trapezoid(screen_w, screen_l, 90, mode="a").reset().vertices().fillet(1)
)


# Holder for the screen (other half of the case)
screen_base = (
    # Basic filleted box shape
    cq.Workplane("bottom")
    .lineTo(-width, 0)
    .lineTo(-width, height)
    .lineTo(0, height)
    .close()
    .extrude(length)
    .faces("<X")
    .shell(-shell_t)
    .edges("|X").fillet(fillet_s)
    # Cutout visible screen area from top face
    .faces(">Z")
    .workplane(centerOption="CenterOfBoundBox")
    .center((width - screen_w) / 2 - screen_left_margin, 0)
    .placeSketch(screen_cutout)
    .cutBlind(-shell_t)
)

exporters.export(screen_base, "screen_base.stl")
